@@ -1,6 +1,7 @@
 #' Is Inconsistent Terms
 #'
 #' Tests whether a term vector has inconsistent elements.
+#' Returns TRUE if includes missing or invalid terms.
 #'
 #' @inheritParams params
 #' @return A logical scalar indicating whether the object's terms are inconsistent.
@@ -12,8 +13,13 @@
 #' is_inconsistent_terms(term("b[2]", "b[1]"))
 #' is_inconsistent_terms(term("b[2]", "b[1,1]"))
 is_inconsistent_terms <- function(x, ...) {
-  if (!length(x)) {
+  if (is_term(x) && !length(x)) {
     return(FALSE)
   }
-  any(!consistent_term(x))
+  if(is_term_rcrd(x) && !length(x)) {
+    return(FALSE)
+  }
+  x <- !consistent_term(x)
+  if(anyNA(x)) return(TRUE)
+  any(x)
 }
