@@ -6,10 +6,15 @@ universals::set_pars
 #' @inherit universals::set_pars
 #'
 #' @export
+#' @examples
+#' term <- as_term(c("b[2]", "a[1]", "b[3,3]"))
+#' set_pars(term, c("x", "y"))
 set_pars.term <- function(x, value, ...) {
   chk_not_any_na(x)
   chk_term(x, validate = "valid")
   chk_pars(value)
+  chk_not_any_na(value)
+  chk_unique(value)
   chk_unused(...)
 
   if (!identical(npars(x), length(value))) {
@@ -26,7 +31,9 @@ set_pars.term <- function(x, value, ...) {
     term_value[term_pars == pars[i]] <- value[i]
   }
 
-  x <- sub(p0("^", .par_name_pattern), "", x)
+  x <- sub(p0("^", par_pattern()), "", x)
   x <- p(term_value, x, sep = "")
   new_term(x)
 }
+
+# FIXME: set_pars.term_rcrd()
