@@ -99,7 +99,7 @@ test_that("as_term others", {
 })
 
 test_that("as_term others", {
-  rlang::scoped_options(lifecycle_verbosity = "quiet")
+  rlang::local_options(lifecycle_verbosity = "quiet")
 
   expect_error(as_term(factor(1)), class = "vctrs_error")
   expect_error(as_term(data.frame(x = 1)), class = "vctrs_error")
